Celery Tasks - durian.tasks — durian v0.0.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- durian v0.0.2 documentation »
- Module API Reference »

# Celery Tasks - durian.tasks

#### Previous topic

Defining Hooks - durian.event

#### Next topic

Django Views - durian.views

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- modules |
- next |
- previous |
- durian v0.0.2 documentation »
- Module API Reference »

© Copyright 2009, Opera Softare (WebTeam). Created using Sphinx 0.6.3.